@@ -1,12 +1,12 @@
 package OpenInteract::Handler::Module;
 
-# $Id: Module.pm,v 1.1.1.1 2001/02/02 06:19:57 lachoy Exp $
+# $Id: Module.pm,v 1.3 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use SPOPS::Secure  qw( :all );
 
 @OpenInteract::Handler::Module::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::Module::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Module::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Module::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Module::default_method    = 'listing';
@@ -95,7 +95,7 @@ sub security_show {
     sec_scope => { user => SEC_SCOPE_USER, group => SEC_SCOPE_GROUP,
                    world => SEC_SCOPE_WORLD } 
   };
-  $R->scrib( 1, "Finding security information for $params->{module_class} in scope $scope" );
+  $R->DEBUG && $R->scrib( 1, "Finding security information for $params->{module_class} in scope $scope" );
 
   my $sec_obj_class = $R->security;
   my ( @assigned_list, @unassigned_list );
@@ -119,8 +119,10 @@ sub security_show {
   # a level. 
 
   else { 
-    my $sec_list  = eval { $sec_obj_class->fetch_group( { where => 'class = ? AND oid = ? AND scope = ?',
-                                                          value => [ $params->{module_class}, '0', $scope ] } ) };
+    my $where = 'class = ? AND object_id = ? AND scope = ?';
+    my $value = [ $params->{module_class}, '0', $scope ];
+    my $sec_list  = eval { $sec_obj_class->fetch_group({ where => $where,
+                                                         value => $value }) };
     if ( $@ ) {
       OpenInteract::Error->set( SPOPS::Error->get );
       $R->throw( { code => 403 } );
@@ -135,7 +137,7 @@ sub security_show {
         warn "Found error on fetching $obj_class $sec->{scope_id}: $@\n";
       }
       next if ( ! $obj );
-     $R->scrib( 1, "Assigned: $obj->{name_field} (", $obj->id, ") with $sec->{level} from security object $sec->{sid}" );
+     $R->DEBUG && $R->scrib( 1, "Assigned: $obj->{name_field} (", $obj->id, ") with $sec->{level} from security object $sec->{sid}" );
       push @assigned_list, { id => $obj->id, name => $obj->{ $name_field },
                              perm => $sec->{level} };
     }
@@ -186,14 +188,16 @@ sub security_edit {
   my $module_info   = $R->CONFIG->{action}->{ $module };
   my $module_class  = $module_info->{class};
   my $sec_obj_class = $R->security;
-  $R->scrib( 1, "Setting scope <$scope> on class $module_class" );
+  $R->DEBUG && $R->scrib( 1, "Setting scope <$scope> on class $module_class" );
 
   # If this is a WORLD scope, just get the level and modify 
 
   if ( $scope eq SEC_SCOPE_WORLD ) {
     my $level = $R->apache->param( 'level' );
-    eval { $class->set_item_security( { class => $module_class, oid => '0',
-                                        scope => SEC_SCOPE_WORLD, level => $level } ); };
+    eval { $class->set_item_security({ class     => $module_class, 
+                                       object_id => '0',
+                                       scope     => SEC_SCOPE_WORLD, 
+                                       level     => $level }) };
     if ( $@ ) {
       warn ">> Error trying to set WORLD security: $@";
       OpenInteract::Error->set( SPOPS::Error->get );
@@ -211,8 +215,10 @@ sub security_edit {
 
     # First retrieve the existing items.
 
-    my $existing_list = eval { $sec_obj_class->fetch_group( { where => 'class = ? AND oid = ? AND scope = ?',
-                                                              value => [ $module_class, '0', $scope ] } ); };
+    my $where = 'class = ? AND object_id = ? AND scope = ?';
+    my $value = [ $module_class, '0', $scope ];
+    my $existing_list = eval { $sec_obj_class->fetch_group({ where => $where,
+                                                             value => $value }) };
     if ( $@ ) {
       OpenInteract::Error->set( SPOPS::Error->get );
       $R->throw( { code => 403 } );
@@ -224,15 +230,17 @@ sub security_edit {
 
     my ( %new_perm );
     my @perm = split /\|/, $R->apache->param( 'assigned_tally' );
-    $R->scrib( 1, scalar @perm, " items in assigned." );
+    $R->DEBUG && $R->scrib( 1, scalar @perm, " items in assigned." );
     foreach my $info ( @perm ) {
       next if ( ! $info );
-      $R->scrib( 1, "Processing <<$info>> from form." );
+      $R->DEBUG && $R->scrib( 1, "Processing <<$info>> from form." );
       my ( $id, $perm, $name ) = split ';', $info;
       $new_perm{ $id } = $perm;
     }
-    eval { $class->set_security( { class => $module_class, oid => '0',
-                                   scope => $scope, level => \%new_perm } ); };
+    eval { $class->set_security({ class     => $module_class, 
+                                  object_id => '0',
+                                  scope     => $scope, 
+                                  level     => \%new_perm } ); };
     if ( $@ ) {
       OpenInteract::Error->set( SPOPS::Error->get );
       $OpenInteract::Error::user_msg = "Cannot set security for module in scope $SCOPE{ $scope }.";
@@ -242,9 +250,11 @@ sub security_edit {
     
     # everything left in %existing_by_id needs to be removed
     foreach my $id ( keys %existing_by_id ) {
-      $R->scrib( 1, "Try to remove $module_class scope $scope ($id)" );
-      eval { $class->remove_item_security( { class => $module_class, oid => '0', 
-                                             scope => $scope, scope_id => $id } ); };
+      $R->DEBUG && $R->scrib( 1, "Try to remove $module_class scope $scope ($id)" );
+      eval { $class->remove_item_security({ class     => $module_class, 
+                                            object_id => '0', 
+                                            scope     => $scope, 
+                                            scope_id  => $id } ); };
       if ( $@ ) {
         OpenInteract::Error->set( SPOPS::Error->get );
         $OpenInteract::Error::user_msg = "Cannot remove security for module in scope $SCOPE{ $scope }.";
