@@ -1,6 +1,6 @@
 package OpenInteract::SQLInstall::Base;
 
-# $Id: Base.pm,v 1.2 2001/05/18 12:21:29 lachoy Exp $
+# $Id: Base.pm,v 1.4 2001/07/13 14:37:04 lachoy Exp $
 
 # Do installation of SQL for this package
 
@@ -10,15 +10,15 @@ use vars qw( %HANDLERS );
 @OpenInteract::SQLInstall::Base::ISA = qw( OpenInteract::SQLInstall );
 
 my %files = (
- tables   => [ 'sessions.sql', 'object_track.sql' ],
- security => [ 'install_security.dat' ],
+   tables   => [ 'sessions.sql', 'object_track.sql', 'object_keys.sql' ],
+   security => [ 'install_security.dat' ],
 );
 
 %HANDLERS = (
- create_structure => { '_default_' => [ 'create_structure', 
-                                        { table_file_list => $files{tables} } ] },
- install_security => { '_default_' => [ 'install_data',
-                                        { data_file_list => $files{security} } ] },
+   create_structure => { '_default_' => [ 'create_structure', 
+                                          { table_file_list => $files{tables} } ] },
+   install_security => { '_default_' => [ 'install_data',
+                                          { data_file_list => $files{security} } ] },
 );
 
 1;
