@@ -1,41 +1,39 @@
 package OpenInteract::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.2 2001/05/30 03:13:03 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.3 2001/07/13 15:08:29 lachoy Exp $
 
 use strict;
 use Data::Dumper qw( Dumper );
 
-$OpenInteract::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 sub fetch_by_name {
-  my ( $class, $name, $package ) = @_;
-  $name = lc $name;
-  my $R = OpenInteract::Request->instance;
-  $R->DEBUG && $R->scrib( 1, "Trying to retrieve template for name ($name) and ",
-                "package ($package)" );
+    my ( $class, $name, $package ) = @_;
+    $name = lc $name;
+    my $R = OpenInteract::Request->instance;
+    $R->DEBUG && $R->scrib( 1, "Trying to retrieve template for name ($name) and ",
+                               "package ($package)" );
 
-  my $where = 'name = ?';
-  my @value = ( $name );
-  if ( $package ) {
-    $where   .= ' AND package = ?';
-    push @value, $package;
-  }
-  my $obj = eval { $class->fetch_group({ 
-                       where => $where, value => \@value 
-                   }) };
-  if ( $@ ) {
-    OpenInteract::Error->set( SPOPS::Error->get );
-    $OpenInteract::Error::user_msg = "Cannot retrieve site template for name " .
-                                     "<<$name>> and package <<$package>>";
-    die $OpenInteract::Error::user_msg;
-  }
-  if ( scalar @{ $obj } > 1 ) {
-    $R->scrib( 0, "Too many items found in response to name <<$name>> ",
-                  "and package <<$package>>! Returning ",
-                  "$obj->[0]->{name} - $obj->[0]->{package}" );
-  }
-  $R->DEBUG && $R->scrib( 2, "Template object(s) found:\n", Dumper( $obj ) );
-  return $obj->[0];
+    my $where = 'name = ?';
+    my @value = ( $name );
+    if ( $package ) {
+        $where   .= ' AND package = ?';
+        push @value, $package;
+    }
+    my $obj = eval { $class->fetch_group({ where => $where, value => \@value }) };
+    if ( $@ ) {
+        OpenInteract::Error->set( SPOPS::Error->get );
+        $OpenInteract::Error::user_msg = "Cannot retrieve site template for name " .
+                                         "<<$name>> and package <<$package>>";
+        die $OpenInteract::Error::user_msg;
+    }
+    if ( scalar @{ $obj } > 1 ) {
+        $R->scrib( 0, "Too many items found in response to name <<$name>> ",
+                      "and package <<$package>>! Returning ",
+                      "$obj->[0]->{name} - $obj->[0]->{package}" );
+    }
+    $R->DEBUG && $R->scrib( 2, "Template object(s) found:\n", Dumper( $obj ) );
+    return $obj->[0];
 }
 
 1;
@@ -96,22 +94,31 @@ for now, not from the filesystem.)
 
 Parameters:
 
- template_name ($)
+=over 4
 
-   Name of the template to retrieve. Currently this name must be
-   unique among all templates.
+=item *
 
- package_name ($) (optional)
+B<template_name> ($)
 
-   Name of the package to use for retrieving the template. If you have
-   this information you should always pass it in -- future versions of
-   this module might require it to ensure a unique template namespace
-   for each package.
+Name of the template to retrieve.
+
+B<package_name> ($)
+
+Name of the package to use for retrieving the template -- both the
+'template_name' and 'package_name' are required to uniquely identify a
+template.
 
 =head1 TO DO
 
+B<Use Template::Toolkit-specifics>
+
+Whatever is in here should be replaced by a L<Template::Provider>
+class that will eventually be written.
+
 =head1 BUGS
 
+None known.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001 intes.net, inc.. All rights reserved.
