@@ -1,11 +1,11 @@
 package OpenInteract::Theme;
 
-# $Id: Theme.pm,v 1.2 2001/05/30 03:13:03 lachoy Exp $
+# $Id: Theme.pm,v 1.3 2001/07/13 15:10:46 lachoy Exp $
 
 use strict;
 use Data::Dumper qw( Dumper );
 
-$OpenInteract::Theme::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Theme::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 
 # Find the properties for this theme and its parent, which
@@ -14,38 +14,38 @@ $OpenInteract::Theme::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.
 # {   property => $obj, ...}
 
 sub discover_properties {
-  my ( $self ) = @_;
-  return $self->{tmp_properties}  if ( ref $self->{tmp_properties} );
+    my ( $self ) = @_;
+    return $self->{tmp_properties}  if ( ref $self->{tmp_properties} );
 
-  my $theme      = $self;
-  my @theme_list = ( $theme );
-  my %properties = ();
+    my $theme      = $self;
+    my @theme_list = ( $theme );
+    my %properties = ();
 
-  # Build up the stack of themes: the main theme we're concerned with
-  # is at the base of the stack. (Yes, we could use recursion, but
-  # this is simple and easy to understand.)
+    # Build up the stack of themes: the main theme we're concerned with
+    # is at the base of the stack. (Yes, we could use recursion, but
+    # this is simple and easy to understand.)
 
-  while ( my $parent = eval { $theme->parent_theme } ) {
-    last unless ( $parent );
-    push @theme_list, $parent;
-    $theme = $parent;
-  }
-
-  # Now that we've built it up, tear it down in reverse
-  # order, so the last theme we use is the one we're concerned
-  # with; each successive theme that overrides properties of a parent
-  # simply overwrites the hash key in %properties
-
-  while ( my $ptheme = pop @theme_list ) {
-    next unless ( $ptheme );
-    my $prop_list = eval { $ptheme->themeprop };
-    foreach my $tp ( @{ $prop_list } ) {
-      $properties{ $tp->{prop} } = $tp;
+    while ( my $parent = eval { $theme->parent_theme } ) {
+        last unless ( $parent );
+        push @theme_list, $parent;
+        $theme = $parent;
     }
-  }
-  my $R = OpenInteract::Request->instance;
-  $R->DEBUG && $R->scrib( 2, "Property list: ", Dumper( \%properties ) );
-  return $self->{tmp_properties} = \%properties;
+
+    # Now that we've built it up, tear it down in reverse
+    # order, so the last theme we use is the one we're concerned
+    # with; each successive theme that overrides properties of a parent
+    # simply overwrites the hash key in %properties
+
+    while ( my $ptheme = pop @theme_list ) {
+        next unless ( $ptheme );
+        my $prop_list = eval { $ptheme->themeprop };
+        foreach my $tp ( @{ $prop_list } ) {
+            $properties{ $tp->{prop} } = $tp;
+        }
+    }
+    my $R = OpenInteract::Request->instance;
+    $R->DEBUG && $R->scrib( 2, "Property list: ", Dumper( \%properties ) );
+    return $self->{tmp_properties} = \%properties;
 }
 
 
@@ -53,27 +53,27 @@ sub discover_properties {
 # into simple name/value pairs
 
 sub all_values {
-  my ( $self ) = @_;
-  my $trans = $self->discover_properties;
-  my %values = ();
-  foreach my $key ( keys %{ $trans }  ) {
-    $values{ $key } = $trans->{ $key }->{value};
-  }
-  return \%values;
+    my ( $self ) = @_;
+    my $trans = $self->discover_properties;
+    my %values = ();
+    foreach my $key ( keys %{ $trans }  ) {
+        $values{ $key } = $trans->{ $key }->{value};
+    }
+    return \%values;
 }
 
 
 # Return the value for a particular theme property
 
 sub property_value {
-  my ( $self, $prop_name ) = @_;
-  $prop_name = lc $prop_name;
-  my $R = OpenInteract::Request->instance;
-  $R->DEBUG && $R->scrib( 2, "Trying to find value for ($prop_name)" );
-  return undef unless ( $prop_name );
-  my $properties = $self->discover_properties;
-  return undef unless ( $properties->{ $prop_name } );
-  return $properties->{ $prop_name }->{value};
+    my ( $self, $prop_name ) = @_;
+    $prop_name = lc $prop_name;
+    my $R = OpenInteract::Request->instance;
+    $R->DEBUG && $R->scrib( 2, "Trying to find value for ($prop_name)" );
+    return undef unless ( $prop_name );
+    my $properties = $self->discover_properties;
+    return undef unless ( $properties->{ $prop_name } );
+    return $properties->{ $prop_name }->{value};
 }
 
 1;
@@ -128,20 +128,18 @@ ThemeProp objects themselves.
 
 Returns: hashref of property-name mapped to ThemeProp object value.
 
-B<property_value( property-name )>
+B<property_value( $property_name )>
 
 Lookup a particular theme property value.
 
-Parameters:
-
- property-name ($)
-
- Name of property for which you want the value.
-
 =head1 TO DO
 
+Nothing known.
+
 =head1 BUGS
 
+None known.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001 intes.net, inc.. All rights reserved.
